Skip to content
They made Python faster with this compiler option episode artwork

May 7, 2024 29 min

They made Python faster with this compiler option

from The Backend Engineering Show with Hussein Nasser Hosted by Hussein Nasser

Fundamentals of Operating Systems Course https://oscourse.win Looks like fedora is compiling cpython with the -o3 flag, which does aggressive function inlining among other optimizations. This seems to improve python benchmarks performance by at most 1.16x at a cost of an extra 3MB in binary size (text segment). Although it does seem to slow down some benchmarks as well though not significantly. O1 - local register allocation, subexpression elimination O2 - Function inlining only small functions O3 - Agressive inlining, SMID 0:00 Intro 1:00 Fedora Linux gets Fast Python 5:40 What is Compiling? 9:00 Compiling with No Optimization 12:10 Compiling with -O1 15:30 Compiling with -O2 20:00 Compiling with -O3 23:20 Showing Numbers Backend Troubleshooting Course https://performance.husseinnasser.com

Episode details come from the podcast's RSS feed.

Embed this episode

Ready to play

They made Python faster with this compiler option

0:00 29:04

No transcript yet.

Requests help us decide what to transcribe next.

Frequently asked questions

How long is this episode of The Backend Engineering Show with Hussein Nasser?

This episode is 29 minutes long.

When was this The Backend Engineering Show with Hussein Nasser episode published?

This episode was published on May 7, 2024.

Can I download this The Backend Engineering Show with Hussein Nasser episode?

Yes. Use the download control on the episode player to save the publisher-provided media file.